@@ -22,14 +22,15 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkinvisible.h>
 #include <gdk/gdkx.h>
 
 #include <gconf/gconf-client.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-help.h>
 
 #include "ice.h"
 #include "logout.h"
@@ -60,68 +61,51 @@ typedef struct {
   int           rowstride;
   GdkWindow    *root_window;
   GdkWindow    *draw_window;
-  GdkPixbuf    *start_pb, *end_pb, *frame;
-  guchar       *start_p, *end_p, *frame_p;
+  GdkPixbuf    *start_pb, *frame;
+  guchar       *start_p, *frame_p;
   GTimeVal      start_time;
   GdkGC        *gc;
+  gboolean      composited;
 } FadeoutData;
 
 static GList *fadeout_windows = NULL;
 
 /* Go for five seconds */
 #define FADE_DURATION 1500.0
+#define SATURATION_TARGET 0.5
 
 static void
 get_current_frame (FadeoutData *fadeout,
 		   double    sat)
 {
-  guchar *sp, *ep, *fp;
+  guchar *sp, *fp;
   int i, j, width, offset;
+  unsigned char lut[256];
+  unsigned int value;
 
   width = fadeout->area.width * 3;
   offset = 0;
+
+  /* compute lookup table */
+  for (value = 0; value < sizeof (lut); value++)
+    {
+      lut[value] = SATURATION_TARGET * value * (1 + sat);
+    }
   
   for (i = 0; i < fadeout->area.height; i++)
     {
       sp = fadeout->start_p + offset;
-      ep = fadeout->end_p   + offset;
       fp = fadeout->frame_p + offset;
 
-      for (j = 0; j < width; j += 3)
+      for (j = 0; j < width; j++)
 	{
-	  guchar r = abs (*(sp++) - ep[0]);
-	  guchar g = abs (*(sp++) - ep[1]);
-	  guchar b = abs (*(sp++) - ep[2]);
-
-	  *(fp++) = *(ep++) + r * sat;
-	  *(fp++) = *(ep++) + g * sat;
-	  *(fp++) = *(ep++) + b * sat;
+	  *(fp++) = lut[*(sp++)];
 	}
 
       offset += fadeout->rowstride;
     }
 }
 
-static void
-darken_pixbuf (GdkPixbuf *pb)
-{
-  int width, height, rowstride;
-  int i, j;
-  guchar *p, *pixels;
-  
-  width     = gdk_pixbuf_get_width (pb) * 3;
-  height    = gdk_pixbuf_get_height (pb);
-  rowstride = gdk_pixbuf_get_rowstride (pb);
-  pixels    = gdk_pixbuf_get_pixels (pb);
-  
-  for (i = 0; i < height; i++)
-    {
-      p = pixels + (i * rowstride);
-      for (j = 0; j < width; j++)
-	p [j] >>= 1;
-    }
-}
-
 static gboolean
 fadeout_callback (FadeoutData *fadeout)
 {
@@ -140,19 +124,8 @@ fadeout_callback (FadeoutData *fadeout)
 
   if (elapsed > FADE_DURATION)
     {
-      gdk_draw_pixbuf (fadeout->draw_window,
-		       fadeout->gc,
-		       fadeout->end_pb,
-		       0, 0,
-		       0, 0,
-		       fadeout->area.width,
-		       fadeout->area.height,
-		       GDK_RGB_DITHER_NONE,
-		       0, 0);
-
       g_object_unref (fadeout->gc);
       g_object_unref (fadeout->start_pb);
-      g_object_unref (fadeout->end_pb);
       g_object_unref (fadeout->frame);
 
       g_free (fadeout);
@@ -162,16 +135,23 @@ fadeout_callback (FadeoutData *fadeout)
 
   percent = elapsed / FADE_DURATION;
 
-  get_current_frame (fadeout, 1.0 - percent);
-  gdk_draw_pixbuf (fadeout->draw_window,
-		   fadeout->gc,
-		   fadeout->frame,
-		   0, 0,
-		   0, 0,
-		   fadeout->area.width,
-		   fadeout->area.height,
-		   GDK_RGB_DITHER_NONE,
-		   0, 0);
+  if (fadeout->composited)
+    {
+      gdk_window_set_opacity (fadeout->draw_window, percent / 2);
+    }
+  else
+    {
+      get_current_frame (fadeout, 1.0 - percent);
+      gdk_draw_pixbuf (fadeout->draw_window,
+		       fadeout->gc,
+		       fadeout->frame,
+		       0, 0,
+		       0, 0,
+		       fadeout->area.width,
+		       fadeout->area.height,
+		       GDK_RGB_DITHER_NONE,
+		       0, 0);
+    }
 
   gdk_flush ();
   
@@ -191,6 +171,7 @@ fadeout_screen (GdkScreen *screen,
 
   fadeout->screen = screen;
   fadeout->monitor = monitor;
+  fadeout->composited = gdk_screen_is_composited (screen);
 
   fadeout->area.x = gsm_screen_get_x (screen, monitor);
   fadeout->area.y = gsm_screen_get_y (screen, monitor);
@@ -198,7 +179,7 @@ fadeout_screen (GdkScreen *screen,
   fadeout->area.height = gsm_screen_get_height (screen, monitor);
 
   fadeout->root_window = gdk_screen_get_root_window (screen);
-  attr.window_type = GDK_WINDOW_CHILD;
+  attr.window_type = GDK_WINDOW_TOPLEVEL;
   attr.x = fadeout->area.x;
   attr.y = fadeout->area.y;
   attr.width = fadeout->area.width;
@@ -221,31 +202,35 @@ fadeout_screen (GdkScreen *screen,
 						    fadeout->area.width,
 						    fadeout->area.height);
   
-  fadeout->end_pb = gdk_pixbuf_copy (fadeout->start_pb);
-  darken_pixbuf (fadeout->end_pb);
-  
   fadeout->frame = gdk_pixbuf_copy (fadeout->start_pb);
   fadeout->rowstride = gdk_pixbuf_get_rowstride (fadeout->start_pb);
 
   fadeout->start_p = gdk_pixbuf_get_pixels (fadeout->start_pb);
-  fadeout->end_p   = gdk_pixbuf_get_pixels (fadeout->end_pb);
   fadeout->frame_p = gdk_pixbuf_get_pixels (fadeout->frame);
   
   values.subwindow_mode = GDK_INCLUDE_INFERIORS;
 
   fadeout->gc = gdk_gc_new_with_values (fadeout->root_window, &values, GDK_GC_SUBWINDOW);
 
-  gdk_window_set_back_pixmap (fadeout->draw_window, NULL, FALSE);
+  if (fadeout->composited)
+    {
+      gdk_window_set_opacity (fadeout->draw_window, 0.0);
+    }
+  else
+    {
+      gdk_window_set_back_pixmap (fadeout->draw_window, NULL, FALSE);
+      gdk_draw_pixbuf (fadeout->draw_window,
+		       fadeout->gc,
+		       fadeout->frame,
+		       0, 0,
+		       0, 0,
+		       fadeout->area.width,
+		       fadeout->area.height,
+		       GDK_RGB_DITHER_NONE,
+		       0, 0);
+    }
+
   gdk_window_show (fadeout->draw_window);
-  gdk_draw_pixbuf (fadeout->draw_window,
-		   fadeout->gc,
-		   fadeout->frame,
-		   0, 0,
-		   0, 0,
-		   fadeout->area.width,
-		   fadeout->area.height,
-		   GDK_RGB_DITHER_NONE,
-		   0, 0);
   
   g_get_current_time (&fadeout->start_time);
   g_idle_add ((GSourceFunc) fadeout_callback, fadeout);
@@ -334,6 +319,7 @@ display_gui (void)
   gboolean reboot_active = FALSE;
   GdmLogoutAction logout_action = GDM_LOGOUT_ACTION_NONE;
   gboolean iris_effect_enabled;
+  gboolean grab_xserver;
   GError *error = NULL;
   GdkScreen *screen;
   int monitor;
@@ -356,11 +342,11 @@ display_gui (void)
 
   gtk_widget_show (invisible);
 
-  iris_effect_enabled = !GTK_IS_ACCESSIBLE (gtk_widget_get_accessible
-  (invisible)) && 
-	                !gtk_widget_is_composited (invisible);
+  iris_effect_enabled = gdk_screen_is_composited (screen) ||
+	                !GTK_IS_ACCESSIBLE (gtk_widget_get_accessible (invisible));
+  grab_xserver = !gdk_screen_is_composited (screen);
 
-  /* Only create a managed window if a11y/compositing manager is enabled */
+  /* Only create a managed window if a11y is enabled */
   if (iris_effect_enabled)
     {
       while (1)
@@ -414,13 +400,13 @@ display_gui (void)
 
   gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_OK);
   gtk_window_set_screen (GTK_WINDOW (box), screen);
-  gtk_window_set_policy (GTK_WINDOW (box), FALSE, FALSE, TRUE);
+  gtk_window_set_resizable (GTK_WINDOW (box), FALSE);
 
   gtk_container_set_border_width (GTK_CONTAINER (box), 5);
 
   if (!autosave)
     {
-      toggle_button = gtk_check_button_new_with_mnemonic (_("_Save current setup"));
+      toggle_button = gtk_check_button_new_with_mnemonic (_("Remember running applications"));
       gtk_widget_show (toggle_button);
       gtk_box_pack_start (GTK_BOX (vbox),
 			  toggle_button,
@@ -489,7 +475,10 @@ display_gui (void)
    */
   if (iris_effect_enabled)
     {
-      XGrabServer (GDK_DISPLAY ());
+      if (grab_xserver)
+        {
+          XGrabServer (GDK_DISPLAY ());
+        }
       gsm_foreach_screen (fadeout_screen);
     }
 
@@ -531,7 +520,11 @@ display_gui (void)
   if (iris_effect_enabled)
     {
       hide_fadeout_windows ();
-      XUngrabServer (GDK_DISPLAY ());
+
+      if (grab_xserver)
+        {
+          XUngrabServer (GDK_DISPLAY ());
+        }
 
       gdk_pointer_ungrab (GDK_CURRENT_TIME);
       gdk_keyboard_ungrab (GDK_CURRENT_TIME);
